@@ -6,6 +6,12 @@ struct Test {
     pub test_text: String,
 }
 
+impl Default for Test {
+    fn default() -> Self {
+        Self { test_text: Default::default() }
+    }
+}
+
 #[tokio::test]
 async fn load_configuration() {
     use anthill_di::{DependencyContext, DependencyLifeCycle};
@@ -20,7 +26,7 @@ async fn load_configuration() {
 
 
     let mut root_context = DependencyContext::new_root();
-    root_context.register_source(|_| Ok(JsonFileConfiguration::<Test>::new("load_configuration.json".to_string()))).await.unwrap();
+    root_context.register_source(|_| Ok(JsonFileConfiguration::<Test>::new("load_configuration.json".to_string(), false))).await.unwrap();
     root_context.register_configuration::<Test, JsonFileConfiguration::<Test>>(DependencyLifeCycle::Transient).await.unwrap();
     
     let configuration = root_context.resolve::<Test>().await.unwrap();
