@@ -6,11 +6,17 @@ struct Test {
     pub test_text: String,
 }
 
+impl Default for Test {
+    fn default() -> Self {
+        Self { test_text: Default::default() }
+    }
+}
+
 #[tokio::test]
 async fn load_snapshot() {
     use anthill_di::{DependencyContext, DependencyLifeCycle};
     use crate::{
-        extensions::{RegisterSnapshotExtension, RegisterSourceExtension},
+        extensions::RegisterSourceExtension,
         source::JsonFileConfiguration,
         ConfigurationSnapshot
     };
@@ -19,10 +25,9 @@ async fn load_snapshot() {
     let mut output = File::create("load_snapshot.json").unwrap();
     write!(output, "{{ \"test_text\": \"test_value\" }}").unwrap();
 
-
     let mut root_context = DependencyContext::new_root();
-    root_context.register_source(|_| Ok(JsonFileConfiguration::<Test>::new("load_snapshot.json".to_string()))).await.unwrap();
-    root_context.register_snapshot::<Test, JsonFileConfiguration::<Test>>(DependencyLifeCycle::Transient).await.unwrap();
+    root_context.register_source(|_| Ok(JsonFileConfiguration::<Test>::new("load_snapshot.json".to_string(), false))).await.unwrap();
+    root_context.register_type::<ConfigurationSnapshot<Test, JsonFileConfiguration::<Test>>>(DependencyLifeCycle::Transient).await.unwrap();
     
     let configuration_snapshot = root_context.resolve::<ConfigurationSnapshot<Test, JsonFileConfiguration::<Test>>>().await.unwrap();
 
